==> apollopay-1.0.1.tar.gz: lib/src/api/entities/app_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:apollopay/src/api/entities/user_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

class App extends Entity {
  String? id;
  String key;
  String name;
  UserType userType;
  App({
    this.id,
    required this.key,
    required this.name,
    required this.userType,
  });

  @override
  App copyWith({
    String? id,
    String? key,
    String? name,
    UserType? type,
  }) {
    return App(
      id: id ?? this.id,
      key: key ?? this.key,
      name: name ?? this.name,
      userType: type ?? this.userType,
    );
  }

  @override
  Map<String, dynamic> toMap() {
    return {
      '_id': id,
      'key': key,
      'name': name,
      'user_type': userType.index,
    };
  }

  factory App.fromMap(Map<String, dynamic> map) {
    return App(
      id: map['_id'] is ObjectId
          ? map['_id'].toHexString()
          : map['_id'].toString(),
      key: map['key'] ?? '',
      name: map['name'] ?? '',
      userType: UserType.values[int.parse(map['user_type'].toString())],
    );
  }

  factory App.fromJson(String source) => App.fromMap(json.decode(source));

  @override
  String toString() {
    return 'App(id: $id, key: $key, name: $name, type: $userType)';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is App &&
        other.id == id &&
        other.key == key &&
        other.name == name &&
        other.userType == userType;
  }

  @override
  int get hashCode {
    return id.hashCode ^ key.hashCode ^ name.hashCode ^ userType.hashCode;
  }
}

==> apollopay-1.0.4.tar.gz: lib/src/api/entities/app_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:apollopay/src/api/entities/user_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

class App extends Entity {
  String? id;
  String key;
  String name;
  UserType userType;
  App({
    this.id,
    required this.key,
    required this.name,
    required this.userType,
  });

  @override
  App copyWith({
    String? id,
    String? key,
    String? name,
    UserType? type,
  }) {
    return App(
      id: id ?? this.id,
      key: key ?? this.key,
      name: name ?? this.name,
      userType: type ?? userType,
    );
  }

  @override
  Map<String, dynamic> toMap({bool withId = true}) {
    return {
      '_id': id,
      'key': key,
      'name': name,
      'user_type': userType.index,
    };
  }

  factory App.fromMap(Map<String, dynamic> map) {
    return App(
      id: map['_id'] is ObjectId
          ? map['_id'].toHexString()
          : map['_id'].toString(),
      key: map['key'] ?? '',
      name: map['name'] ?? '',
      userType: UserType.values[int.parse(map['user_type'].toString())],
    );
  }

  factory App.fromJson(String source) => App.fromMap(json.decode(source));

  @override
  String toString() {
    return 'App(id: $id, key: $key, name: $name, type: $userType)';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is App &&
        other.id == id &&
        other.key == key &&
        other.name == name &&
        other.userType == userType;
  }

  @override
  int get hashCode {
    return id.hashCode ^ key.hashCode ^ name.hashCode ^ userType.hashCode;
  }
}
